package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.WorkerMarginLogMapper;
import com.ruoyi.system.domain.WorkerMarginLog;
import com.ruoyi.system.service.IWorkerMarginLogService;

/**
 * 师傅质保金明细Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class WorkerMarginLogServiceImpl implements IWorkerMarginLogService 
{
    @Autowired
    private WorkerMarginLogMapper workerMarginLogMapper;

    /**
     * 查询师傅质保金明细
     * 
     * @param id 师傅质保金明细主键
     * @return 师傅质保金明细
     */
    @Override
    public WorkerMarginLog selectWorkerMarginLogById(Integer id)
    {
        return workerMarginLogMapper.selectWorkerMarginLogById(id);
    }

    /**
     * 查询师傅质保金明细列表
     * 
     * @param workerMarginLog 师傅质保金明细
     * @return 师傅质保金明细
     */
    @Override
    public List<WorkerMarginLog> selectWorkerMarginLogList(WorkerMarginLog workerMarginLog)
    {
        return workerMarginLogMapper.selectWorkerMarginLogList(workerMarginLog);
    }

    /**
     * 新增师傅质保金明细
     * 
     * @param workerMarginLog 师傅质保金明细
     * @return 结果
     */
    @Override
    public int insertWorkerMarginLog(WorkerMarginLog workerMarginLog)
    {
        return workerMarginLogMapper.insertWorkerMarginLog(workerMarginLog);
    }

    /**
     * 修改师傅质保金明细
     * 
     * @param workerMarginLog 师傅质保金明细
     * @return 结果
     */
    @Override
    public int updateWorkerMarginLog(WorkerMarginLog workerMarginLog)
    {
        return workerMarginLogMapper.updateWorkerMarginLog(workerMarginLog);
    }

    /**
     * 批量删除师傅质保金明细
     * 
     * @param ids 需要删除的师傅质保金明细主键
     * @return 结果
     */
    @Override
    public int deleteWorkerMarginLogByIds(Integer[] ids)
    {
        return workerMarginLogMapper.deleteWorkerMarginLogByIds(ids);
    }

    /**
     * 删除师傅质保金明细信息
     * 
     * @param id 师傅质保金明细主键
     * @return 结果
     */
    @Override
    public int deleteWorkerMarginLogById(Integer id)
    {
        return workerMarginLogMapper.deleteWorkerMarginLogById(id);
    }
}
