package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.WorkerMarginLog;
import com.ruoyi.system.service.IWorkerMarginLogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 师傅质保金明细Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/WorkerMarginLog")
public class WorkerMarginLogController extends BaseController
{
    @Autowired
    private IWorkerMarginLogService workerMarginLogService;

    /**
     * 查询师傅质保金明细列表
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerMarginLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(WorkerMarginLog workerMarginLog)
    {
        startPage();
        List<WorkerMarginLog> list = workerMarginLogService.selectWorkerMarginLogList(workerMarginLog);
        return getDataTable(list);
    }

    /**
     * 导出师傅质保金明细列表
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerMarginLog:export')")
    @Log(title = "师傅质保金明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WorkerMarginLog workerMarginLog)
    {
        List<WorkerMarginLog> list = workerMarginLogService.selectWorkerMarginLogList(workerMarginLog);
        ExcelUtil<WorkerMarginLog> util = new ExcelUtil<WorkerMarginLog>(WorkerMarginLog.class);
        util.exportExcel(response, list, "师傅质保金明细数据");
    }

    /**
     * 获取师傅质保金明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerMarginLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(workerMarginLogService.selectWorkerMarginLogById(id));
    }

    /**
     * 新增师傅质保金明细
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerMarginLog:add')")
    @Log(title = "师傅质保金明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WorkerMarginLog workerMarginLog)
    {
        return toAjax(workerMarginLogService.insertWorkerMarginLog(workerMarginLog));
    }

    /**
     * 修改师傅质保金明细
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerMarginLog:edit')")
    @Log(title = "师傅质保金明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WorkerMarginLog workerMarginLog)
    {
        return toAjax(workerMarginLogService.updateWorkerMarginLog(workerMarginLog));
    }

    /**
     * 删除师傅质保金明细
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerMarginLog:remove')")
    @Log(title = "师傅质保金明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(workerMarginLogService.deleteWorkerMarginLogByIds(ids));
    }
}
